@@ -1,8 +1,7 @@
-from typing import Union, Any, Generator, List, Optional
-from MySQLdb import Connection
-from pandas import ExcelFile, read_excel, DataFrame, concat
 from numpy import arange, concatenate, array
+from pandas import ExcelFile, read_excel, DataFrame, concat
 from re import compile, IGNORECASE
+from typing import Union, Any, Generator, List, Optional
 
 class MySQL:
 	''' Connector for the MySQLdb backend with a handful of helpers. '''
@@ -35,6 +34,7 @@ class MySQL:
 	def get_cursor(self):
 		''' Returns the open cursor and initializes the connection if required. '''
 		if self._cursor is None:
+			from MySQLdb import Connection
 			self._connection = Connection(**self._connection)
 			self._cursor = self._connection.cursor()
 		return self._cursor
@@ -42,7 +42,7 @@ class MySQL:
 	def execute(self, query: str, params: tuple = None):
 		''' Wrapper for the MySQLdb execute method that won't send the params argument
 		if the params are empty, thus avoiding the need to replace % with %%. '''
-		return self.get_cursor().execute(query, params if len(params) else None)
+		return self.get_cursor().execute(query, params if params is not None and len(params) else None)
 
 	def find(self, query: str, *params: tuple) -> dict:
 		''' Returns a {column: value} dict of the first selected row. '''
